@@ -47,6 +47,9 @@
 #'  the official MathJax CDN. The "local" option uses a local version of MathJax
 #'  (which is copied into the output directory). You can pass an alternate URL
 #'  or pass \code{NULL} to exclude MathJax entirely.
+#'@param section_divs Wrap sections in <div> tags (or <section> tags in HTML5),
+#'  and attach identifiers to the enclosing <div> (or <section>) rather than the
+#'  header itself.
 #'@param template Pandoc template to use for rendering. Pass "default" to use
 #'  the rmarkdown package default template; pass \code{NULL} to use pandoc's
 #'  built-in template; pass a path to use a custom template that you've created.
@@ -189,6 +192,7 @@ html_document <- function(toc = FALSE,
                           toc_depth = 3,
                           toc_float = FALSE,
                           number_sections = FALSE,
+                          section_divs = TRUE,
                           fig_width = 7,
                           fig_height = 5,
                           fig_retina = 2,
@@ -216,7 +220,8 @@ html_document <- function(toc = FALSE,
   args <- c("--standalone")
 
   # use section divs
-  args <- c(args, "--section-divs")
+  if (section_divs)
+    args <- c(args, "--section-divs")
 
   # table of contents
   args <- c(args, pandoc_toc_args(toc, toc_depth))
@@ -289,15 +294,7 @@ html_document <- function(toc = FALSE,
 
   # add highlight.js html_dependency if required
   if (identical(template, "default") && is_highlightjs(highlight)) {
-    extra_dependencies <- append(extra_dependencies, list(
-      htmlDependency(
-        "highlightjs",
-        version = "1.1",
-        src = rmarkdown_system_file("rmd/h/highlightjs-1.1"),
-        script = "highlight.js",
-        stylesheet = paste0(highlight, ".css")
-      )
-    ))
+    extra_dependencies <- append(extra_dependencies, list(html_dependency_highlightjs(highlight)))
   }
 
   # numbered sections
